==> symfony_6.4.16%2Bdfsg.orig.tar.xz: symfony-6.4.16/src/Symfony/Component/Intl/Resources/data/scripts/ha.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Arab' => 'Larabci',
        'Aran' => 'Rubutun Nastaliq',
        'Armn' => 'Armeniyanci',
        'Beng' => 'Bangla',
        'Bopo' => 'Bopomofo',
        'Brai' => 'Rubutun Makafi',
        'Cakm' => 'Chakma',
        'Cans' => 'Haɗaɗɗun Gaɓoɓin harshe na Asali na Kanada',
        'Cher' => 'Cherokee',
        'Cyrl' => 'Cyrillic',
        'Deva' => 'Devanagari',
        'Ethi' => 'Ethiopic',
        'Geor' => 'Georgian',
        'Grek' => 'Girkanci',
        'Gujr' => 'Gujarati',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han tare da Bopomofo',
        'Hang' => 'Yaren Hangul',
        'Hani' => 'Mutanen Han na ƙasar Sin',
        'Hans' => 'Sauƙaƙaƙƙe',
        'Hant' => 'Na gargajiya',
        'Hebr' => 'Ibrananci',
        'Hira' => 'Tsarin Rubutun Hiragana',
        'Hrkt' => 'kalaman Jafananci',
        'Jpan' => 'Jafanis',
        'Kana' => 'Tsarin Rubutun Katakana',
        'Khmr' => 'Yaren Khmer',
        'Knda' => 'Yaren Kannada',
        'Kore' => 'Rubutun Koriya',
        'Laoo' => 'Yan lao',
        'Latn' => 'Latin',
        'Mlym' => 'Yaren Malayalam',
        'Mong' => 'Na kasar Mongolia',
        'Mtei' => 'Meitei Mayek',
        'Mymr' => 'Ƙasar Myanmar',
        'Nkoo' => 'N’Ko',
        'Olck' => 'Ol Chiki',
        'Orya' => 'Yaren Odia',
        'Rohg' => 'Hanifi',
        'Sinh' => 'Yaren Sinhala',
        'Sund' => 'Sudananci',
        'Syrc' => 'Siriyanci',
        'Taml' => 'Yaren Tamil',
        'Telu' => 'Yaren Telugu',
        'Tfng' => 'Tifinagh',
        'Thaa' => 'Yaren Thaana',
        'Tibt' => 'Yaren Tibet',
        'Vaii' => 'Vai',
        'Yiii' => 'Yi',
        'Zmth' => 'Alamar Lissafi',
        'Zsye' => 'Alama ta hoto',
        'Zsym' => 'Alamomi',
        'Zxxx' => 'Ba rubutacce ba',
        'Zyyy' => 'Gama-gari',
    ],
];

==> symfony_7.0.4%2Bdfsg.orig.tar.xz: symfony-7.0.4/src/Symfony/Component/Intl/Resources/data/scripts/ha.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Arab' => 'Larabci',
        'Aran' => 'Rubutun Nastaliq',
        'Armn' => 'Armeniyawa',
        'Beng' => 'Bangla',
        'Bopo' => 'Bopomofo',
        'Brai' => 'Rubutun Makafi',
        'Cakm' => 'Chakma',
        'Cans' => 'Haɗaɗɗun Gaɓoɓin ʼYan Asali na Kanada',
        'Cher' => 'Cherokee',
        'Cyrl' => 'Cyrillic',
        'Deva' => 'Devanagari',
        'Ethi' => 'Ethiopic',
        'Geor' => 'Georgian',
        'Grek' => 'Girka',
        'Gujr' => 'Gujarati',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han tare da Bopomofo',
        'Hang' => 'Yaren Hangul',
        'Hani' => 'Mutanen Han na ƙasar Sin',
        'Hans' => 'Sauƙaƙaƙƙen',
        'Hant' => 'Na gargajiya',
        'Hebr' => 'Ibrananci',
        'Hira' => 'Tsarin Rubutun Hiragana',
        'Hrkt' => 'kalaman Jafananci',
        'Jamo' => 'Jamo',
        'Jpan' => 'Jafanis',
        'Kana' => 'Tsarin Rubutun Katakana',
        'Khmr' => 'Yaren Khmer',
        'Knda' => 'Yaren Kannada',
        'Kore' => 'Rubutun Koriya',
        'Laoo' => 'Yan lao',
        'Latn' => 'Latin',
        'Mlym' => 'Yaren Malayalam',
        'Mong' => 'Na kasar Mongolia',
        'Mtei' => 'Meitei Mayek',
        'Mymr' => 'Ƙasar Myanmar',
        'Nkoo' => 'N’Ko',
        'Olck' => 'Ol Chiki',
        'Orya' => 'Yaren Odia',
        'Rohg' => 'Hanifi',
        'Sinh' => 'Yaren Sinhala',
        'Sund' => 'Sudananci',
        'Syrc' => 'Siriyanci',
        'Taml' => 'Yaren Tamil',
        'Telu' => 'Yaren Telugu',
        'Tfng' => 'Tifinagh',
        'Thaa' => 'Yaren Thaana',
        'Thai' => 'Thai',
        'Tibt' => 'Yaren Tibet',
        'Vaii' => 'Vai',
        'Yiii' => 'Yi',
        'Zmth' => 'Alamar Lissafi',
        'Zsye' => 'Alama ta hoto',
        'Zsym' => 'Alamomi',
        'Zxxx' => 'Ba rubutacce ba',
        'Zyyy' => 'Gama-gari',
    ],
];
